@@ -1,17 +1,17 @@
 from django.db import models
-from wagtail.core.models import Page
 from wagtail.core.fields import StreamField
+from wagtail.core.models import Page
 
-from wagtail_color_panel.fields import ColorField
-from wagtail_color_panel.edit_handlers import NativeColorPanel
 from wagtail_color_panel.blocks import NativeColorBlock
+from wagtail_color_panel.edit_handlers import NativeColorPanel
+from wagtail_color_panel.fields import ColorField
 
 
 class PageWithColorField(Page):
     color = ColorField()
 
     content_panels = Page.content_panels + [
-        NativeColorPanel('color'),
+        NativeColorPanel("color"),
     ]
 
 
@@ -24,6 +24,8 @@ class PageWithDefaultValue(Page):
 
 
 class PageWithStreamfield(Page):
-    body = StreamField([
-        ('color', NativeColorBlock()),
-    ])
+    body = StreamField(
+        [
+            ("color", NativeColorBlock()),
+        ]
+    )
